﻿(function (window) {
    var u = {};
    var isAndroid = (/android/gi).test(navigator.appVersion);
    var uzStorage = function () {
        var ls = window.localStorage;
        if (isAndroid) {
            ls = os.localStorage();
        }
        return ls;
    };
    function parseArguments(url, data, fnSuc, dataType) {
        if (typeof (data) == 'function') {
            dataType = fnSuc;
            fnSuc = data;
            data = undefined;
        }
        if (typeof (fnSuc) != 'function') {
            dataType = fnSuc;
            fnSuc = undefined;
        }
        return {
            url: url,
            data: data,
            fnSuc: fnSuc,
            dataType: dataType
        };
    }
    u.trim = function (str) {
        if (String.prototype.trim) {
            return str == null ? "" : String.prototype.trim.call(str);
        } else {
            return str.replace(/(^\s*)|(\s*$)/g, "");
        }
    };
    u.trimAll = function (str) {
        return str.replace(/\s*/g, '');
    };
    u.isElement = function (obj) {
        return !!(obj && obj.nodeType == 1);
    };
    u.isArray = function (obj) {
        if (Array.isArray) {
            return Array.isArray(obj);
        } else {
            return obj instanceof Array;
        }
    };
    u.isEmptyObject = function (obj) {
        if (JSON.stringify(obj) === '{}') {
            return true;
        }
        return false;
    };
    u.addEvt = function (el, name, fn, useCapture) {
        if (!u.isElement(el)) {
            console.warn('$api.addEvt Function need el param, el param must be DOM Element');
            return;
        }
        useCapture = useCapture || false;
        if (el.addEventListener) {
            el.addEventListener(name, fn, useCapture);
        }
    };
    u.rmEvt = function (el, name, fn, useCapture) {
        if (!u.isElement(el)) {
            console.warn('$api.rmEvt Function need el param, el param must be DOM Element');
            return;
        }
        useCapture = useCapture || false;
        if (el.removeEventListener) {
            el.removeEventListener(name, fn, useCapture);
        }
    };
    u.one = function (el, name, fn, useCapture) {
        if (!u.isElement(el)) {
            console.warn('$api.one Function need el param, el param must be DOM Element');
            return;
        }
        useCapture = useCapture || false;
        var that = this;
        var cb = function () {
            fn && fn();
            that.rmEvt(el, name, cb, useCapture);
        };
        that.addEvt(el, name, cb, useCapture);
    };
    u.dom = function (el, selector) {
        if (arguments.length === 1 && typeof arguments[0] == 'string') {
            if (document.querySelector) {
                return document.querySelector(arguments[0]);
            }
        } else if (arguments.length === 2) {
            if (el.querySelector) {
                return el.querySelector(selector);
            }
        }
    };
    u.domAll = function (el, selector) {
        if (arguments.length === 1 && typeof arguments[0] == 'string') {
            if (document.querySelectorAll) {
                return document.querySelectorAll(arguments[0]);
            }
        } else if (arguments.length === 2) {
            if (el.querySelectorAll) {
                return el.querySelectorAll(selector);
            }
        }
    };
    u.byId = function (id) {
        return document.getElementById(id);
    };
    u.first = function (el, selector) {
        if (arguments.length === 1) {
            if (!u.isElement(el)) {
                console.warn('$api.first Function need el param, el param must be DOM Element');
                return;
            }
            return el.children[0];
        }
        if (arguments.length === 2) {
            return this.dom(el, selector + ':first-child');
        }
    };
    u.last = function (el, selector) {
        if (arguments.length === 1) {
            if (!u.isElement(el)) {
                console.warn('$api.last Function need el param, el param must be DOM Element');
                return;
            }
            var children = el.children;
            return children[children.length - 1];
        }
        if (arguments.length === 2) {
            return this.dom(el, selector + ':last-child');
        }
    };
    u.eq = function (el, index) {
        return this.dom(el, ':nth-child(' + index + ')');
    };
    u.not = function (el, selector) {
        return this.domAll(el, ':not(' + selector + ')');
    };
    u.prev = function (el) {
        if (!u.isElement(el)) {
            console.warn('$api.prev Function need el param, el param must be DOM Element');
            return;
        }
        var node = el.previousSibling;
        if (node.nodeType && node.nodeType === 3) {
            node = node.previousSibling;
            return node;
        }
    };
    u.next = function (el) {
        if (!u.isElement(el)) {
            console.warn('$api.next Function need el param, el param must be DOM Element');
            return;
        }
        var node = el.nextSibling;
        if (node.nodeType && node.nodeType === 3) {
            node = node.nextSibling;
            return node;
        }
    };
    u.closest = function (el, selector) {
        if (!u.isElement(el)) {
            console.warn('$api.closest Function need el param, el param must be DOM Element');
            return;
        }
        var doms, targetDom;
        var isSame = function (doms, el) {
            var i = 0, len = doms.length;
            for (i; i < len; i++) {
                if (doms[i].isEqualNode(el)) {
                    return doms[i];
                }
            }
            return false;
        };
        var traversal = function (el, selector) {
            doms = u.domAll(el.parentNode, selector);
            targetDom = isSame(doms, el);
            while (!targetDom) {
                el = el.parentNode;
                if (el != null && el.nodeType == el.DOCUMENT_NODE) {
                    return false;
                }
                traversal(el, selector);
            }

            return targetDom;
        };

        return traversal(el, selector);
    };
    u.contains = function (parent, el) {
        var mark = false;
        if (el === parent) {
            mark = true;
            return mark;
        } else {
            do {
                el = el.parentNode;
                if (el === parent) {
                    mark = true;
                    return mark;
                }
            } while (el === document.body || el === document.documentElement);

            return mark;
        }

    };
    u.remove = function (el) {
        if (el && el.parentNode) {
            el.parentNode.removeChild(el);
        }
    };
    u.attr = function (el, name, value) {
        if (!u.isElement(el)) {
            console.warn('$api.attr Function need el param, el param must be DOM Element');
            return;
        }
        if (arguments.length == 2) {
            return el.getAttribute(name);
        } else if (arguments.length == 3) {
            el.setAttribute(name, value);
            return el;
        }
    };
    u.removeAttr = function (el, name) {
        if (!u.isElement(el)) {
            console.warn('$api.removeAttr Function need el param, el param must be DOM Element');
            return;
        }
        if (arguments.length === 2) {
            el.removeAttribute(name);
        }
    };
    u.hasCls = function (el, cls) {
        if (!u.isElement(el)) {
            console.warn('$api.hasCls Function need el param, el param must be DOM Element');
            return;
        }
        if (el.className.indexOf(cls) > -1) {
            return true;
        } else {
            return false;
        }
    };
    u.addCls = function (el, cls) {
        if (!u.isElement(el)) {
            console.warn('$api.addCls Function need el param, el param must be DOM Element');
            return;
        }
        if ('classList' in el) {
            el.classList.add(cls);
        } else {
            var preCls = el.className;
            var newCls = preCls + ' ' + cls;
            el.className = newCls;
        }
        return el;
    };
    u.removeCls = function (el, cls) {
        if (!u.isElement(el)) {
            console.warn('$api.removeCls Function need el param, el param must be DOM Element');
            return;
        }
        if ('classList' in el) {
            el.classList.remove(cls);
        } else {
            var preCls = el.className;
            var newCls = preCls.replace(cls, '');
            el.className = newCls;
        }
        return el;
    };
    u.toggleCls = function (el, cls) {
        if (!u.isElement(el)) {
            console.warn('$api.toggleCls Function need el param, el param must be DOM Element');
            return;
        }
        if ('classList' in el) {
            el.classList.toggle(cls);
        } else {
            if (u.hasCls(el, cls)) {
                u.addCls(el, cls);
            } else {
                u.removeCls(el, cls);
            }
        }
        return el;
    };
    u.val = function (el, val) {
        if (!u.isElement(el)) {
            console.warn('$api.val Function need el param, el param must be DOM Element');
            return;
        }
        if (arguments.length === 1) {
            switch (el.tagName) {
                case 'SELECT':
                    var value = el.options[el.selectedIndex].value;
                    return value;
                    break;
                case 'INPUT':
                    return el.value;
                    break;
                case 'TEXTAREA':
                    return el.value;
                    break;
            }
        }
        if (arguments.length === 2) {
            switch (el.tagName) {
                case 'SELECT':
                    el.options[el.selectedIndex].value = val;
                    return el;
                    break;
                case 'INPUT':
                    el.value = val;
                    return el;
                    break;
                case 'TEXTAREA':
                    el.value = val;
                    return el;
                    break;
            }
        }

    };
    u.prepend = function (el, html) {
        if (!u.isElement(el)) {
            console.warn('$api.prepend Function need el param, el param must be DOM Element');
            return;
        }
        el.insertAdjacentHTML('afterbegin', html);
        return el;
    };
    u.append = function (el, html) {
        if (!u.isElement(el)) {
            console.warn('$api.append Function need el param, el param must be DOM Element');
            return;
        }
        el.insertAdjacentHTML('beforeend', html);
        return el;
    };
    u.before = function (el, html) {
        if (!u.isElement(el)) {
            console.warn('$api.before Function need el param, el param must be DOM Element');
            return;
        }
        el.insertAdjacentHTML('beforebegin', html);
        return el;
    };
    u.after = function (el, html) {
        if (!u.isElement(el)) {
            console.warn('$api.after Function need el param, el param must be DOM Element');
            return;
        }
        el.insertAdjacentHTML('afterend', html);
        return el;
    };
    u.html = function (el, html) {
        if (!u.isElement(el)) {
            console.warn('$api.html Function need el param, el param must be DOM Element');
            return;
        }
        if (arguments.length === 1) {
            return el.innerHTML;
        } else if (arguments.length === 2) {
            el.innerHTML = html;
            return el;
        }
    };
    u.text = function (el, txt) {
        if (!u.isElement(el)) {
            console.warn('$api.text Function need el param, el param must be DOM Element');
            return;
        }
        if (arguments.length === 1) {
            return el.textContent;
        } else if (arguments.length === 2) {
            el.textContent = txt;
            return el;
        }
    };
    u.offset = function (el) {
        if (!u.isElement(el)) {
            console.warn('$api.offset Function need el param, el param must be DOM Element');
            return;
        }
        var sl = Math.max(document.documentElement.scrollLeft, document.body.scrollLeft);
        var st = Math.max(document.documentElement.scrollTop, document.body.scrollTop);

        var rect = el.getBoundingClientRect();
        return {
            l: rect.left + sl,
            t: rect.top + st,
            w: el.offsetWidth,
            h: el.offsetHeight
        };
    };
    u.css = function (el, css) {
        if (!u.isElement(el)) {
            console.warn('$api.css Function need el param, el param must be DOM Element');
            return;
        }
        if (typeof css == 'string' && css.indexOf(':') > 0) {
            el.style && (el.style.cssText += ';' + css);
        }
    };
    u.cssVal = function (el, prop) {
        if (!u.isElement(el)) {
            console.warn('$api.cssVal Function need el param, el param must be DOM Element');
            return;
        }
        if (arguments.length === 2) {
            var computedStyle = window.getComputedStyle(el, null);
            return computedStyle.getPropertyValue(prop);
        }
    };
    u.jsonToStr = function (json) {
        if (typeof json === 'object') {
            return JSON && JSON.stringify(json);
        }
    };
    u.strToJson = function (str) {
        if (typeof str === 'string') {
            return JSON && JSON.parse(str);
        }
    };
    u.setStorage = function (key, value) {
        if (arguments.length === 2) {
            var v = value;
            if (typeof v == 'object') {
                v = JSON.stringify(v);
                v = 'obj-' + v;
            } else {
                v = 'str-' + v;
            }
            var ls = uzStorage();
            if (ls) {
                ls.setItem(key, v);
            }
        }
    };
    u.getStorage = function (key) {
        var ls = uzStorage();
        if (ls) {
            var v = ls.getItem(key);
            if (!v) { return; }
            if (v.indexOf('obj-') === 0) {
                v = v.slice(4);
                return JSON.parse(v);
            } else if (v.indexOf('str-') === 0) {
                return v.slice(4);
            }
        }
    };
    u.rmStorage = function (key) {
        var ls = uzStorage();
        if (ls && key) {
            ls.removeItem(key);
        }
    };
    u.clearStorage = function () {
        var ls = uzStorage();
        if (ls) {
            ls.clear();
        }
    };


    /*by king*/
    u.fixIos7Bar = function (el) {
        if (!u.isElement(el)) {
            console.warn('$api.fixIos7Bar Function need el param, el param must be DOM Element');
            return;
        }
        var strDM = api.systemType;
        if (strDM == 'ios') {
            var strSV = api.systemVersion;
            var numSV = parseInt(strSV, 10);
            var fullScreen = api.fullScreen;
            var iOS7StatusBarAppearance = api.iOS7StatusBarAppearance;
            if (numSV >= 7 && !fullScreen && iOS7StatusBarAppearance) {
                el.style.paddingTop = '20px'; 
            }
        }
    };
    u.fixStatusBar = function (el) {
        if (!u.isElement(el)) {
            console.warn('$api.fixStatusBar Function need el param, el param must be DOM Element');
            return;
        }
        var sysType = api.systemType;
        if (sysType == 'ios') {
            u.fixIos7Bar(el);
        } else if (sysType == 'android') {
            var ver = api.systemVersion;
            ver = parseFloat(ver);
            if (ver >= 4.4) {
                el.style.paddingTop = '25px';
            }
        }
    };
    u.post = function (/*url,data,fnSuc,dataType*/) {
        var argsToJson = parseArguments.apply(null, arguments);
        var json = {};
        var fnSuc = argsToJson.fnSuc;
        argsToJson.url && (json.url = argsToJson.url);
        argsToJson.data && (json.data = argsToJson.data);
        if (argsToJson.dataType) {
            var type = argsToJson.dataType.toLowerCase();
            if (type == 'text' || type == 'json') {
                json.dataType = type;
            }
        } else {
            json.dataType = 'json';
        }
        json.method = 'post';
        api.ajax(json,
            function (ret, err) {
                if (ret) {
                    fnSuc && fnSuc(ret);
                }
            }
        );
    };
    u.get = function (/*url,fnSuc,dataType*/) {
        var argsToJson = parseArguments.apply(null, arguments);
        var json = {};
        var fnSuc = argsToJson.fnSuc;
        argsToJson.url && (json.url = argsToJson.url);
        //argsToJson.data && (json.data = argsToJson.data);
        if (argsToJson.dataType) {
            var type = argsToJson.dataType.toLowerCase();
            if (type == 'text' || type == 'json') {
                json.dataType = type;
            }
        } else {
            json.dataType = 'text';
        }
        json.method = 'get';
        api.ajax(json,
            function (ret, err) {
                if (ret) {
                    fnSuc && fnSuc(ret);
                }
            }
        );
    }; 
    
    /*self*/
    u.execScript=function(name,method){
   		api.execScript({
            name: name,
            script: method
        });
    }
    u.getPicture=function(sourceType,callBack){
    	try{
    		api.getPicture({
			    sourceType:sourceType,
			    encodingType: 'jpg',
			    mediaValue: 'pic',
			    destinationType: 'base64',
			    quality:50,
			    targetWidth:1000,
			    saveToPhotoAlbum: true,
			}, function(ret, err){ 
			    if (ret) {
			        callBack(ret.data);
			    }else{
		    		callBack(err.msg);
			    }
			});
    	}catch(e){
    		//TODO handle the exception
    	}
    }
    u.cameraTool=function(callBack){
    	var cameraTool = api.require('cameraTool');
		cameraTool.openCamera(function(ret, err){
			callBack(ret);
		});
    }
	u.showProgress=function(title,model){
		try{
			var model=model||false;
			api.showProgress({
	            style: 'default',
	            animationType: 'fade',
	            title:title,
	            modal: model
	        });	
		}catch(e){
			//TODO handle the exception
		}
	}
	u.hideProgress=function(){
		api.hideProgress();
	}
    u.alert=function(msg){
    	try{
    		api.alert({msg:msg});	
    	}catch(e){
    		alert(msg);
    	}
    	
    }
    u.alertObj = function(obj) {
		alert(JSON.stringify(obj));
	}
    u.close=function(name){
    	try{
    		api.closeWin({
			    name:name,
			});
    	}catch(e){
    		history.back();
    	}
    }
    u.closeToWin=function(name){
    	try{
    		api.closeToWin({
			    name:name,
			});
    	}catch(e){
    		history.back();
    	}
    }
    u.openWin=function(name,url){
    	try{
    		api.openWin({
			    name:name,
			    url:url,
			    slidBackEnabled:false,
			    vScrollBarEnabled:false,
			    hScrollBarEnabled:false
			});
    	}catch(e){
    		window.location.href=url;
    	}
    }
    u.closeFrame = function(name) {
		api.closeFrame({
			name: name
		});
	}
    u.sendEvent=function(name,value){
		api.sendEvent({
		    name: name,
		    extra:value
		});
	}
	u.addEvent=function(name,callBack){
		api.addEventListener({
		    name: name
		},function(ret, err){
		    callBack(ret.value);
		});
	}
	u.removeEvent=function(name){
		api.removeEventListener({
		    name: name
		});
	}
	u.openFrame=function(url,name,rect){
		api.openFrame({
		    name: name,
		    url: url,
		    rect: rect,
		    bounces: true,
		    vScrollBarEnabled: false,
		    hScrollBarEnabled: false
		});
	}
	u.keyback=function(calllBack){
		api.addEventListener({
		    name:'keyback'
		},function(ret,err){
		    calllBack(ret);
		});
	}
	u.actionSheet = function(data, callBack) {
		try{
			api.actionSheet({
				title: '提示',
			    cancelTitle: '取消',
			    buttons: data
			},function(ret,err){
			    var re = ret.buttonIndex-1;
				callBack(re);
			});
		}catch(e){
			//TODO handle the exception
		}
	}
	u.confirm=function(msg,buttons,callBack){
		try{
			api.confirm({
			    msg: msg,
			    buttons: buttons
			},function( ret, err ){
			    if( ret ){
			        callBack(ret.buttonIndex);
			    }
			});
		}catch(e){
			//TODO handle the exception
		}
	}
	u.call=function(type,number){
		try{
			api.call({
	            type: type,
	            number: number
	        });
		}catch(e){
			//TODO handle the exception
		}
	}
	u.imageClip=function(url,callBack){
		try{
			var imageClip = api.require('imageClip');
			imageClip.open({
			    path: url,
			    clipRect:{
			        x:api.winWidth/2-150,
			        y:api.winHeight/2-150,
			        w:300,
			        h:300,
			        fixation:true
			    }
			},function( ret, err ){        
			    if( ret.status ){
			       callBack(ret);
			    }
			});
		}catch(e){
			//TODO handle the exception
		}
	}
	u.open = function(url, name, pageParam) {
		name = name || url;
		try {
			api.openWin({
				name: name,
				reload: false,
				url: url,
				vScrollBarEnabled:false,
				slidBackEnabled:false,
				allowEdit:true,
				pageParam: pageParam
			})
		} catch (e) { 
			$api.setStorage(name,pageParam);
			window.location.href = url;
		}
	}
	u.freshHeader=function(callBack){
		api.setRefreshHeaderInfo({
		    visible: true,
		    loadingImg: '',
		    bgColor: '#ccc',
		    textColor: '#fff',
		    textDown: '下拉刷新...',
		    textUp: '松开刷新...',
		    showTime: true
		}, function(ret, err){
			callBack();
		});
	}
	u.closeFreshHeader=function(){
		api.refreshHeaderLoadDone();
	}
	u.freshBottom=function(callBack){
		api.addEventListener({
		    name:'scrolltobottom',
		},function(ret,err){
			callBack();
		});
	}
	u.picker=function(type,val,callBack){
		api.openPicker({
		    type: type,
		    date: val,
		    title: '选择日期'
		},function( ret, err ){
		    if( ret ){
		    	callBack(ret);
		    }
		});
	}
	u.toast = function(msg, time, location) {
		try{
			api.toast({
			    msg: msg,
			    duration: time,
			    location: location,
			    global:true
			});
		}catch(e){
		}
	};
	u.notify=function(content,hour,minute,callBack){
		var content=content||'吃药了';
		api.notification({
			sound : 'default',
			light:true,
		    notify: {
		        content:content,
		        extra:'drag' 
		    },
		    alarm: {
		        hour: hour,
		        minutes: minute,
		        daysOfWeek: [1,2,3,4,5,6,7]
		    }
		},function( ret, err ){
			callBack(ret.id);
		});
	}
	u.cancelNotify=function(id){
		var id=id||-1;
		api.cancelNotification({
		    id:id
		});
	}
	u.setBounces=function(name,bounces){
		api.setFrameAttr({
		    name: name,
		    bounces: bounces,
		});
	}
	u.download=function(url,callBack){
		api.download({
		    url: url,
		    savePath:'',
		    report: false,
		    cache: true,
		    allowResume: true
		}, function(ret, err) {
		    callBack(ret);
		});
	}
	u.androidHeader=function(){
		try{
			var systemVersion = api.systemVersion; 
		    var systemType = api.systemType;
		    if(systemType==='android'){
		    	var version=systemVersion.replace(/\./g,"");
		    	if(version<440){ 
		    		$('.header-top').removeClass('header-top');
		    		$('.m-header-72').addClass('m-header-46');
		    		$('.m-header-72').removeClass('m-header-72');
		    		return 44;
		    	}else{
		    		return 70;
		    	}
		    }else{
		    	return 70;
		    }
		}catch(e){
		}
	}
	u.headerTop=function(url,pageParam){
	    var systemType = api.systemType;
	    if(systemType==='ios'){
	    	api.openFrame({
			    name: url,
			    url: url,
			    rect: {
			        x: 0,
			        y: 0,
			        w: $(window).width(),
			        h: 70
			    },
			    pageParam: pageParam,
			    bounces: false,
			    vScrollBarEnabled: false,
			    hScrollBarEnabled: false
			});
	    }
	}
    /*end*/ 
    u.androidHeader();
    window.$api = u;
})(window);
//简化js拼接
String.prototype.tpl = function (obj) {
	return this.replace(/\{\$(\w+)\}/g,function (_,bb){
		try{
			var data = eval("obj."+bb);
			return data === undefined ? eval(bb):data;
		}catch(e){
			try{return eval(bb);}catch(e){return _;}
		}
	});
}
//$api.serverURL = "http://192.168.127.141/";
//$api.serverURL = "http://192.168.127.39/";
//$api.serverURL = "http://192.168.127.87/";
//$api.serverURL = "http://www.csethhealthcare.com/";
$api.serverURL = "https://www.chcpay.com/";

$api.getServerData = function (param, callback,files) { 
    param = param || {};
    if (!param["token"]){
    	param["token"] = $api.getStorage("token");
    }
    var data1 = { className: "mgd", deviceId: api.deviceId };
    for (var tmp in param) {
        data1[tmp] = param[tmp];
    }
    var data2 = { values: data1 ,files:files};
    if (data1.methodName == "Login"){
        api.ajax({ url: $api.serverURL + "ajax.ashx", data: data2, method: "post", cache: true, dataType: "json" }, callback);
    }
    else {
        api.ajax({ url: $api.serverURL + "ajax.ashx", data: data2, method: "post", cache: true, dataType: "json",timeout:90}, function (ret, err) {
            if (ret&&ret.ret == "error" && ret.msg == "未登录") {
                $api.openWinJS("jumploginformindex", "widget://login.html");
                api.hideProgress();
            }
            else {
                if (err&&err.statusCode == "403"){
					err = { msg: "网络限制访问" };
                }else{
					err={msg:"服务器错误"};
                	callback(ret, err);                	
                }
            }
        });
    }
}
 
$api.openWinJS = function (name, url) {
    api.openWin({ name: name, url: url, vScrollBarEnabled: false, hScrollBarEnabled: false, scaleEnabled: false, animation: { type: "push", subType: "from_right", duration: 300} });
}
//金钱转化
String.prototype.formatMoney = function (type) {
    if (this == null || this == "") return "0";
    if (/[^-?0-9\.]/.test(this)) return "0";
    var s = this.replace(/^(-?\d*)$/, "$1.");
    s = (s + "00").replace(/(\d*\.\d\d)\d*/, "$1");
    s = s.replace(".", ",");
    var re = /(\d)(\d{3},)/;
    while (re.test(s))
        s = s.replace(re, "$1,$2");
    s = s.replace(/,(\d\d)$/, ".$1");
    if (type == 0) {// ����С��λ(Ĭ������С��λ)
        var a = s.split(".");
        if (a[1] == "00") {
            s = a[0];
        }
    }
    return s;
}

//电话截取
String.prototype.toCutMobile = function () {
    var s = "";
    s = this.substring(0,3)+"****"+this.substring(this.length-4);
    return s;
}